FlvFileHeader

Struct FlvFileHeader 

pub struct FlvFileHeader {
    pub signature: [u8; 3],
    pub version: u8,
    pub flags: u8,
    pub has_audio: bool,
    pub has_video: bool,
    pub data_offset: u32,
}
The header part of FLV file.

Fields

signature: [u8; 3]

Signature bytes are always “FLV” (0x46, 0x4c, 0x56).

version: u8

File version (0x01 for FLV version 1).

flags: u8

TypeFlagsReserved 5 bits Shall be 0. TypeFlagsAudio 1 bit 1 = Audio tags are present. TypeFlagsReserved 1 bit Shall be 0. TypeFlagsVideo 1 bit 1 = Video tags are present.

has_audio: bool

The flag that represents whether the audio exists in FLV file.

has_video: bool

The flag that represents whether the video exists in FLV file.

data_offset: u32

The length of this header in bytes, usually has a value of 9 for FLV version 1.

Implementations

Source

impl FlvFileHeader

pub fn parse(input: &[u8]) -> IResult<&[u8], FlvFileHeader>

Parse FLV file header.